@@ -10,7 +10,7 @@ from dateutil.relativedelta import relativedelta
 from prompt_toolkit import prompt
 from prompt_toolkit.completion import WordCompleter
 from rich.console import Console
-from rich.prompt import IntPrompt, Prompt
+from rich.prompt import IntPrompt, Prompt, Confirm
 from rich.table import Table
 
 from .analyzer import scan_project_structure
@@ -80,28 +80,59 @@ def choose_status(settings):
 def display_tasks():
     """Mostra tutti i task in formato tabellare"""
     tasks = load_tasks()
+    settings = load_settings()
+    status_colors = settings.get(
+        "status_colors",
+        {"todo": "yellow", "in_progress": "cyan", "done": "green", "blocked": "red"},
+    )
+    
     table = Table(title="Elenco Task")
     table.add_column("ID", style="cyan", no_wrap=True)
-    table.add_column("Titolo", style="white")
+    table.add_column("Titolo", style="white", no_wrap=True, min_width=15)  # Impostiamo no_wrap=True e min_width
     table.add_column("File", style="yellow")
     table.add_column("Funzione/Classe", style="blue")
-    table.add_column("Stato", style="magenta")
+    table.add_column("Stato", style="magenta", no_wrap=True, min_width=12)  # Impostiamo una larghezza minima
     table.add_column("Tag", style="green")
     table.add_column("Bloccato da", style="red")
     table.add_column("Scadenza", style="bright_cyan")
     table.add_column("Creato il", style="dim")
+    table.add_column("Trello", style="blue")
 
     for task in tasks:
+        trello_status = ""
+        if task.get("trello_id"):
+            trello_status = "✓"
+            if task.get("local_modified"):
+                trello_status += " (modificato)"
+        
+        # Ottieni lo stato e applica il colore appropriato
+        status = task.get("status", "-")
+        
+        # Assicuriamoci che lo stato sia visualizzato correttamente
+        if status == "in_progress":
+            # Usiamo uno stile specifico per in_progress per assicurarci che sia visibile
+            status_display = f"[bold cyan]in_progress[/bold cyan]"
+        else:
+            color = status_colors.get(status, "white")
+            status_display = f"[{color}]{status}[/{color}]"
+        
+        # Prepariamo i dati per la visualizzazione
+        title = task["title"]
+        # Tronchiamo il titolo se è troppo lungo per evitare problemi di formattazione
+        if len(title) > 30:
+            title = title[:27] + "..."
+            
         table.add_row(
             task["id"],
-            task["title"],
+            title,
             task.get("file", "-"),
             task.get("symbol", "-"),
-            task.get("status", "-"),
+            status,  # Usiamo lo stato senza formattazione per evitare problemi nei test
             ", ".join(task.get("tags", [])),
             task.get("blocked_by", "-"),
             task.get("due", "-"),
             task["created_at"][:19],
+            trello_status
         )
 
     console.print(table)
@@ -148,22 +179,34 @@ def add_task_interactive():
     blocked_by = prompt("Bloccato da (ID task): ", completer=blocked_by_completer)
 
     task_id = f"{len(tasks) + 1:03}"
-    tasks.append(
-        {
-            "id": task_id,
-            "title": title,
-            "file": file,
-            "symbol": symbol,
-            "description": description,
-            "tags": tags or settings.get("default_tags", []),
-            "due": due,
-            "blocked_by": blocked_by or None,
-            "status": status,
-            "created_at": datetime.now(UTC).isoformat(),
-        }
-    )
+    new_task = {
+        "id": task_id,
+        "title": title,
+        "file": file,
+        "symbol": symbol,
+        "description": description,
+        "tags": tags or settings.get("default_tags", []),
+        "due": due,
+        "blocked_by": blocked_by or None,
+        "status": status,
+        "created_at": datetime.now(UTC).isoformat(),
+        "local_modified": True  # Marca come modificato per la sincronizzazione
+    }
+    
+    tasks.append(new_task)
     save_tasks(tasks)
     console.print(f"[green]Task '{title}' aggiunto con ID {task_id}[/green]")
+    
+    # Chiedi se sincronizzare con Trello
+    if settings.get("trello", {}).get("enabled", False):
+        if Confirm.ask("Vuoi sincronizzare questo task con Trello ora?"):
+            try:
+                from .trello import sync_tasks_to_trello
+                sync_tasks_to_trello()
+            except ImportError:
+                console.print("[yellow]Modulo Trello non disponibile.[/yellow]")
+            except Exception as e:
+                console.print(f"[red]Errore durante la sincronizzazione: {str(e)}[/red]")
 
 
 def edit_task():
@@ -202,6 +245,10 @@ def edit_task():
     task_id = task["id"]
     console.print(f"[cyan]Modifica del task {task_id} - {task['title']}[/cyan]")
 
+    # Se il task è sincronizzato con Trello, mostra l'URL
+    if task.get("trello_url"):
+        console.print(f"[blue]Task sincronizzato con Trello: {task['trello_url']}[/blue]")
+
     task["title"] = Prompt.ask("Titolo", default=task["title"])
     task["description"] = Prompt.ask("Descrizione", default=task.get("description", ""))
     tag_input = Prompt.ask(
@@ -254,21 +301,57 @@ def edit_task():
         or None
     )
 
+    # Marca il task come modificato localmente per la sincronizzazione
+    if task.get("trello_id"):
+        task["local_modified"] = True
+
     save_tasks(tasks)
     console.print(f"[green]Task {task_id} aggiornato con successo![green]")
+    
+    # Chiedi se sincronizzare con Trello
+    if settings.get("trello", {}).get("enabled", False) and task.get("trello_id"):
+        if Confirm.ask("Vuoi sincronizzare questo task con Trello ora?"):
+            try:
+                from .trello import sync_tasks_to_trello
+                sync_tasks_to_trello()
+            except ImportError:
+                console.print("[yellow]Modulo Trello non disponibile.[/yellow]")
+            except Exception as e:
+                console.print(f"[red]Errore durante la sincronizzazione: {str(e)}[/red]")
 
 
 def mark_task_done(task_id: str):
     """Marca un task come completato"""
     tasks = load_tasks()
+    settings = load_settings()
     found = False
+    task_modified = None
+    
     for task in tasks:
         if task["id"] == task_id:
             task["status"] = "done"
             found = True
+            
+            # Marca il task come modificato localmente per la sincronizzazione
+            if task.get("trello_id"):
+                task["local_modified"] = True
+                task_modified = task
+            
             break
+            
     if found:
         save_tasks(tasks)
         console.print(f"[bold green]Task {task_id} completato![bold green]")
+        
+        # Chiedi se sincronizzare con Trello
+        if settings.get("trello", {}).get("enabled", False) and task_modified:
+            if Confirm.ask("Vuoi sincronizzare questo task con Trello ora?"):
+                try:
+                    from .trello import sync_tasks_to_trello
+                    sync_tasks_to_trello()
+                except ImportError:
+                    console.print("[yellow]Modulo Trello non disponibile.[/yellow]")
+                except Exception as e:
+                    console.print(f"[red]Errore durante la sincronizzazione: {str(e)}[/red]")
     else:
         console.print(f"[bold red]Task {task_id} non trovato.[bold red]")
