@@ -77,6 +77,14 @@ class TrelloClient:
         response = requests.get(url, params=params)
         response.raise_for_status()
         return response.json()
+        
+    def get_card(self, card_id: str) -> Dict[str, Any]:
+        """Ottiene i dettagli di una card specifica"""
+        url = f"{self.base_url}/cards/{card_id}"
+        params = self._get_auth_params()
+        response = requests.get(url, params=params)
+        response.raise_for_status()
+        return response.json()
     
     def create_card(self, list_id: str, name: str, desc: str = "", due: Optional[str] = None, 
                    labels: Optional[List[str]] = None, pos: str = "bottom") -> Dict[str, Any]:
@@ -136,6 +144,152 @@ class TrelloClient:
         response = requests.post(url, params=params)
         response.raise_for_status()
         return response.json()
+    
+    # Metodi per i campi personalizzati
+    
+    def get_custom_fields(self, board_id: str) -> List[Dict[str, Any]]:
+        """Ottiene i campi personalizzati di una board"""
+        url = f"{self.base_url}/boards/{board_id}/customFields"
+        params = self._get_auth_params()
+        response = requests.get(url, params=params)
+        response.raise_for_status()
+        return response.json()
+    
+    def create_custom_field(self, board_id: str, name: str, field_type: str, 
+                           display_cardfront: bool = True, options: List[Dict[str, str]] = None) -> Dict[str, Any]:
+        """Crea un nuovo campo personalizzato in una board
+        
+        Args:
+            board_id: ID della board
+            name: Nome del campo
+            field_type: Tipo del campo (text, number, date, checkbox, list)
+            display_cardfront: Se mostrare il campo sul fronte della card
+            options: Opzioni per i campi di tipo 'list'
+        """
+        url = f"{self.base_url}/customFields"
+        
+        data = {
+            "idModel": board_id,
+            "modelType": "board",
+            "name": name,
+            "type": field_type,
+            "pos": "bottom",
+            "display_cardfront": display_cardfront
+        }
+        
+        if options and field_type == "list":
+            data["options"] = options
+        
+        params = self._get_auth_params()
+        response = requests.post(url, params=params, json=data)
+        response.raise_for_status()
+        return response.json()
+    
+    def set_custom_field_value(self, card_id: str, field_id: str, value: Any) -> Dict[str, Any]:
+        """Imposta il valore di un campo personalizzato per una card
+        
+        Args:
+            card_id: ID della card
+            field_id: ID del campo personalizzato
+            value: Valore da impostare (il formato dipende dal tipo di campo)
+        """
+        url = f"{self.base_url}/card/{card_id}/customField/{field_id}/item"
+        
+        # Il formato del valore dipende dal tipo di campo
+        if isinstance(value, bool):
+            data = {"value": {"checked": "true" if value else "false"}}
+        elif isinstance(value, (int, float)):
+            data = {"value": {"number": str(value)}}
+        elif isinstance(value, dict) and "id" in value:  # Per i campi di tipo 'list'
+            data = {"idValue": value["id"]}
+        else:
+            data = {"value": {"text": str(value)}}
+        
+        params = self._get_auth_params()
+        response = requests.put(url, params=params, json=data)
+        response.raise_for_status()
+        return response.json()
+    
+    def get_custom_field_value(self, card_id: str, field_id: str) -> Dict[str, Any]:
+        """Ottiene il valore di un campo personalizzato per una card"""
+        url = f"{self.base_url}/cards/{card_id}/customField/{field_id}/item"
+        params = self._get_auth_params()
+        response = requests.get(url, params=params)
+        response.raise_for_status()
+        return response.json()
+    
+    # Metodi per i campi personalizzati
+    
+    def get_custom_fields(self, board_id: str) -> List[Dict[str, Any]]:
+        """Ottiene i campi personalizzati di una board"""
+        url = f"{self.base_url}/boards/{board_id}/customFields"
+        params = self._get_auth_params()
+        response = requests.get(url, params=params)
+        response.raise_for_status()
+        return response.json()
+    
+    def create_custom_field(self, board_id: str, name: str, field_type: str, 
+                           display_cardfront: bool = True, options: List[Dict[str, str]] = None) -> Dict[str, Any]:
+        """Crea un nuovo campo personalizzato in una board
+        
+        Args:
+            board_id: ID della board
+            name: Nome del campo
+            field_type: Tipo del campo (text, number, date, checkbox, list)
+            display_cardfront: Se mostrare il campo sul fronte della card
+            options: Opzioni per i campi di tipo 'list'
+        """
+        url = f"{self.base_url}/customFields"
+        
+        data = {
+            "idModel": board_id,
+            "modelType": "board",
+            "name": name,
+            "type": field_type,
+            "pos": "bottom",
+            "display_cardfront": display_cardfront
+        }
+        
+        if options and field_type == "list":
+            data["options"] = options
+        
+        params = self._get_auth_params()
+        response = requests.post(url, params=params, json=data)
+        response.raise_for_status()
+        return response.json()
+    
+    def set_custom_field_value(self, card_id: str, field_id: str, value: Any) -> Dict[str, Any]:
+        """Imposta il valore di un campo personalizzato per una card
+        
+        Args:
+            card_id: ID della card
+            field_id: ID del campo personalizzato
+            value: Valore da impostare (il formato dipende dal tipo di campo)
+        """
+        url = f"{self.base_url}/card/{card_id}/customField/{field_id}/item"
+        
+        # Il formato del valore dipende dal tipo di campo
+        if isinstance(value, bool):
+            data = {"value": {"checked": "true" if value else "false"}}
+        elif isinstance(value, (int, float)):
+            data = {"value": {"number": str(value)}}
+        elif isinstance(value, dict) and "id" in value:  # Per i campi di tipo 'list'
+            data = {"idValue": value["id"]}
+        else:
+            data = {"value": {"text": str(value)}}
+        
+        params = self._get_auth_params()
+        response = requests.put(url, params=params, json=data)
+        response.raise_for_status()
+        return response.json()
+    
+    def get_custom_field_value(self, card_id: str, field_id: str) -> Dict[str, Any]:
+        """Ottiene il valore di un campo personalizzato per una card"""
+        url = f"{self.base_url}/cards/{card_id}/customField/{field_id}/item"
+        params = self._get_auth_params()
+        response = requests.get(url, params=params)
+        response.raise_for_status()
+        return response.json()
 
 
 def setup_trello_integration(quick_setup: bool = False):
@@ -276,6 +430,12 @@ def setup_trello_integration(quick_setup: bool = False):
         
         # Aggiorna le impostazioni
         settings["trello"] = trello_config
+            
+            # Aggiungi il nome del progetto
+            project_name = settings.get("project_name", "")
+            if project_name:
+                description += f"\n\nProgetto: {project_name}"
+                
         
         # Salva le impostazioni
         from .config import SETTINGS_FILE
@@ -287,7 +447,12 @@ def setup_trello_integration(quick_setup: bool = False):
         
         # Chiedi se sincronizzare subito
         if Confirm.ask("Vuoi sincronizzare i task esistenti con Trello ora?"):
+            console.print("[bold]Sincronizzazione bidirezionale in corso...[/bold]")
+            # Prima sincronizziamo da locale a Trello
             sync_tasks_to_trello()
+            # Poi sincronizziamo da Trello a locale per assicurarci che tutto sia allineato
+            sync_tasks_from_trello()
+            console.print("[bold green]Sincronizzazione completata![/bold green]")
             
     except Exception as e:
         console.print(f"[bold red]Errore durante la configurazione: {str(e)}[/bold red]")
@@ -346,8 +511,14 @@ def sync_tasks_to_trello():
             
             # Prepara la descrizione
             description = task.get("description", "")
+            
+            # Aggiungi il nome del progetto
+            project_name = settings.get("project_name", "")
+            if project_name:
+                description += f"\n\nProgetto: {project_name}"
+                
             if task.get("file"):
-                description += f"\n\nFile: {task['file']}"
+                description += f"\nFile: {task['file']}"
             if task.get("symbol"):
                 description += f"\nFunzione/Classe: {task['symbol']}"
             if task.get("tags"):
@@ -359,6 +530,9 @@ def sync_tasks_to_trello():
             description += f"\n\nID DevNotes: {task['id']}"
             
             try:
+                # Ottieni i campi personalizzati configurati
+                custom_fields = trello_config.get("custom_fields", {})
+                
                 if "trello_id" in task:
                     # Aggiorna la card esistente
                     card_data = {
@@ -370,7 +544,7 @@ def sync_tasks_to_trello():
                     if task.get("due"):
                         card_data["due"] = task["due"]
                     
-                    client.update_card(task["trello_id"], card_data)
+                    card = client.update_card(task["trello_id"], card_data)
                 else:
                     # Crea una nuova card
                     card = client.create_card(
@@ -384,6 +558,43 @@ def sync_tasks_to_trello():
                     task["trello_id"] = card["id"]
                     task["trello_url"] = card["url"]
                 
+                # Aggiorna i campi personalizzati se sono configurati
+                if custom_fields:
+                    try:
+                        # Imposta il campo progetto
+                        if "project" in custom_fields:
+                            client.set_custom_field_value(
+                                card_id=card["id"],
+                                field_id=custom_fields["project"],
+                                value=settings.get("project_name", "")
+                            )
+                        
+                        # Imposta il campo file
+                        if "file" in custom_fields and task.get("file"):
+                            client.set_custom_field_value(
+                                card_id=card["id"],
+                                field_id=custom_fields["file"],
+                                value=task["file"]
+                            )
+                        
+                        # Imposta il campo funzione/classe
+                        if "symbol" in custom_fields and task.get("symbol"):
+                            client.set_custom_field_value(
+                                card_id=card["id"],
+                                field_id=custom_fields["symbol"],
+                                value=task["symbol"]
+                            )
+                        
+                        # Imposta il campo ID DevNotes
+                        if "devnotes_id" in custom_fields:
+                            client.set_custom_field_value(
+                                card_id=card["id"],
+                                field_id=custom_fields["devnotes_id"],
+                                value=task["id"]
+                            )
+                    except Exception as e:
+                        console.print(f"[yellow]Errore durante l'aggiornamento dei campi personalizzati: {str(e)}[/yellow]")
+                
                 # Rimuovi il flag di modifica locale
                 if "local_modified" in task:
                     del task["local_modified"]
@@ -429,6 +640,60 @@ def sync_tasks_from_trello():
             except Exception as e:
                 console.print(f"[red]Errore durante il recupero delle card dalla lista {list_id}: {str(e)}[/red]")
             
+            # Crea i campi personalizzati
+            task3 = progress.add_task("[cyan]Creazione dei campi personalizzati...", total=4)
+            
+            try:
+                # Campo per il progetto
+                project_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="Progetto",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Campo per il file
+                file_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="File",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Campo per la funzione/classe
+                symbol_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="Funzione/Classe",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Campo per l'ID DevNotes
+                id_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="ID DevNotes",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Salva gli ID dei campi personalizzati
+                custom_fields = {
+                    "project": project_field["id"],
+                    "file": file_field["id"],
+                    "symbol": symbol_field["id"],
+                    "devnotes_id": id_field["id"]
+                }
+            except Exception as e:
+                console.print(f"[yellow]Errore durante la creazione dei campi personalizzati: {str(e)}[/yellow]")
+                console.print("[yellow]I campi personalizzati non saranno disponibili.[/yellow]")
+                custom_fields = {}
+                # Completiamo comunque la barra di progresso
+                progress.update(task3, completed=4)
+            
             progress.update(list_progress, advance=1)
     
     # Aggiorna i task esistenti e crea nuovi task
@@ -552,7 +817,8 @@ def create_devnotes_board():
             # Crea le liste
             task2 = progress.add_task("[cyan]Creazione delle liste...", total=len(statuses))
             
-            status_to_list_map = {}
+            status_to_list_map                "custom_fields": custom_fields,
+ = {}
             for i, status in enumerate(statuses):
                 list_name = status_to_list_name.get(status, status.capitalize())
                 trello_list = client.create_list(
@@ -563,6 +829,60 @@ def create_devnotes_board():
                 status_to_list_map[status] = trello_list["id"]
                 progress.update(task2, advance=1)
             
+            # Crea i campi personalizzati
+            task3 = progress.add_task("[cyan]Creazione dei campi personalizzati...", total=4)
+            
+            try:
+                # Campo per il progetto
+                project_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="Progetto",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Campo per il file
+                file_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="File",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Campo per la funzione/classe
+                symbol_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="Funzione/Classe",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Campo per l'ID DevNotes
+                id_field = client.create_custom_field(
+                    board_id=board["id"],
+                    name="ID DevNotes",
+                    field_type="text",
+                    display_cardfront=True
+                )
+                progress.update(task3, advance=1)
+                
+                # Salva gli ID dei campi personalizzati
+                custom_fields = {
+                    "project": project_field["id"],
+                    "file": file_field["id"],
+                    "symbol": symbol_field["id"],
+                    "devnotes_id": id_field["id"]
+                }
+            except Exception as e:
+                console.print(f"[yellow]Errore durante la creazione dei campi personalizzati: {str(e)}[/yellow]")
+                console.print("[yellow]I campi personalizzati non saranno disponibili.[/yellow]")
+                custom_fields = {}
+                # Completiamo comunque la barra di progresso
+                progress.update(task3, completed=4)
+            
             # Salva la configurazione
             trello_config = {
                 "api_key": client.api_key,
@@ -570,6 +890,7 @@ def create_devnotes_board():
                 "board_id": board["id"],
                 "board_name": board["name"],
                 "status_to_list_map": status_to_list_map,
+                "custom_fields": custom_fields,
                 "enabled": True
             }
             
@@ -587,7 +908,12 @@ def create_devnotes_board():
         
         # Chiedi se sincronizzare subito
         if Confirm.ask("Vuoi sincronizzare i task esistenti con Trello ora?"):
+            console.print("[bold]Sincronizzazione bidirezionale in corso...[/bold]")
+            # Prima sincronizziamo da locale a Trello
             sync_tasks_to_trello()
+            # Poi sincronizziamo da Trello a locale per assicurarci che tutto sia allineato
+            sync_tasks_from_trello()
+            console.print("[bold green]Sincronizzazione completata![/bold green]")
             
     except Exception as e:
         console.print(f"[bold red]Errore durante la creazione della board: {str(e)}[/bold red]")
